@@ -13,7 +13,7 @@ import termios
 import time
 from contextlib import contextmanager
 
-__version__ = 'cplay-ng 5.3.0'
+__version__ = '5.3.1'
 
 AUDIO_EXTENSIONS = [
     'mp3', 'ogg', 'oga', 'opus', 'flac', 'm4a', 'm4b', 'wav', 'mid', 'wma'
@@ -220,7 +220,7 @@ class Player:
             return
         self.is_playing = True
         self._playing += 1
-        if get_mpv_version() > (0, 38, 0):
+        if get_mpv_version() >= (0, 38, 0):
             self._ipc('loadfile', self.path, 'replace', 0, 'start=%i' % self.position)
         else:
             self._ipc('loadfile', self.path, 'replace', 'start=%i' % self.position)
@@ -350,7 +350,7 @@ class List:
             if self.position + i == self.active:
                 attr |= curses.A_BOLD
             s_item = self.format_item(item)
-            s_item = space_between('  ' + s_item, '', app.cols)
+            s_item = space_between(f'  {s_item}', '', app.cols)
             yield (s_item, attr)
         for _i in range(max(0, self.rows - len(items))):
             yield ''
@@ -408,9 +408,9 @@ class Filelist(List):
         self.set_path(os.getcwd())
 
     def get_title(self):
-        title = 'Filelist: %s/' % self.path.rstrip('/')
+        title = f'Filelist: {self.path.rstrip("/")}/'
         if self.rsearch_str:
-            title += 'search "%s"/' % self.rsearch_str
+            title += f'search "{self.rsearch_str}"/'
         return title
 
     def format_item(self, item):
@@ -516,7 +516,7 @@ class Playlist(List):
     def get_title(self):
         title = 'Playlist'
         if self.path:
-            title += ' ' + os.path.basename(self.path)
+            title += f' {os.path.basename(self.path)}'
             if self.items != self.items_written:
                 title += '*'
         if self.repeat:
@@ -642,7 +642,7 @@ class Playlist(List):
         try:
             with open(path, 'w') as fh:
                 for item in self.items:
-                    fh.write('%s\n' % item)
+                    fh.write(f'{item}\n')
                 self.path = path
                 self.items_written = self.items.copy()
         except OSError:
@@ -698,11 +698,11 @@ class Application:
         self.resize_in, self.resize_out = os.pipe2(os.O_NONBLOCK)
 
     def refresh_dimensions(self):
-        self.rows, self.cols = screen.getmaxyx()
+        self.rows, self.cols = self.screen.getmaxyx()
 
     def on_resize(self):
         curses.endwin()
-        screen.refresh()
+        self.screen.refresh()
         self.refresh_dimensions()
         self.tab.set_cursor(app.tab.cursor)
 
@@ -728,11 +728,11 @@ class Application:
         yield self.format_progress()
 
         if self.input.active:
-            status = self.input.prompt + self.input.str + '█'
+            status = f'{self.input.prompt}{self.input.str}█'
         elif self.tab == helplist:
-            status = __version__
+            status = f'cplay-ng {__version__}'
         elif player.is_playing:
-            status = 'Playing %s' % player.get_title()
+            status = f'Playing {player.get_title()}'
         else:
             status = ''
 
@@ -752,15 +752,15 @@ class Application:
                     and line == self.old_lines[i]
                 ):
                     continue
-                screen.move(i, 0)
-                screen.clrtoeol()
+                self.screen.move(i, 0)
+                self.screen.clrtoeol()
                 if isinstance(line, str):
-                    screen.insstr(i, 0, line, 0)
+                    self.screen.insstr(i, 0, line, 0)
                 else:
-                    screen.insstr(i, 0, *line)
+                    self.screen.insstr(i, 0, *line)
             # make sure cursor is in a meaningful position for a11y
-            screen.move(self.tab.cursor - self.tab.position + 2, 0)
-            screen.refresh()
+            self.screen.move(self.tab.cursor - self.tab.position + 2, 0)
+            self.screen.refresh()
         except curses.error:
             pass
         self.old_lines = lines
@@ -809,7 +809,7 @@ class Application:
                         self.on_resize()
                         self.render(force=True)
                     elif key.fileobj is sys.stdin:
-                        self.process_key(screen.get_wch())
+                        self.process_key(self.screen.get_wch())
                     elif key.fileobj is player.socket:
                         player.parse_progress()
 
@@ -825,11 +825,10 @@ filelist = Filelist()
 helplist = HelpList()
 app = Application()
 
-screen = curses.initscr()
-
 
 def main():
-    screen.keypad(True)  # noqa: FBT003
+    app.screen = curses.initscr()
+    app.screen.keypad(True)  # noqa: FBT003
     curses.cbreak()
     curses.noecho()
     curses.meta(True)  # noqa: FBT003
